@@ -152,7 +152,7 @@ def make_upload_header(token, org_id):
 		'Authorization': f'Zoho-oauthtoken {token.access}',
 		'feature': 'bulk-write',
 		'X-CRM-ORG': org_id,
-		'Content-Type': "multipart/form"
+		#'Content-Type': "multipart/form"
 	}
 
 def upload_csv(token, org_id, module, filename):
@@ -172,7 +172,7 @@ def upload_csv(token, org_id, module, filename):
 
 	elif response.status_code >= 400 and response.status_code < 500:
 		print(response.status_code)
-		print(response.content)
+		print(response.reason)
 		print("Refreshing token")
 		token.generate()
 		return upload_csv(token,org_id, module, filename)
